@@ -50,6 +50,7 @@ class fileviewer(object):
                  "1e":"Field Scan", 
                  "1w":"Frequency Comb", 
                  "1f":"Frequency Scan", 
+                 "1x":"Frequency Scan", 
                  "1n":"Rb Cell Scan", 
                  "20":"SLR", 
                  '2e':'Randomized Frequency Scan',
@@ -117,10 +118,10 @@ class fileviewer(object):
         # viewer frame -------------------------------------------------------
         view_frame = ttk.Frame(file_tab, borderwidth=2)
         
-        self.text_nw = Text(view_frame, width=88, height=20, state='normal')
-        self.text_ne = Text(view_frame, width=88, height=20, state='normal')
-        self.text_sw = Text(view_frame, width=88, height=20, state='normal')
-        self.text_se = Text(view_frame, width=88, height=20, state='normal')
+        self.text_nw = Text(view_frame, width=88, height=20, state='normal', wrap='none')
+        self.text_ne = Text(view_frame, width=88, height=20, state='normal', wrap='none')
+        self.text_sw = Text(view_frame, width=88, height=20, state='normal', wrap='none')
+        self.text_se = Text(view_frame, width=88, height=20, state='normal', wrap='none')
         
         ttk.Label(view_frame, text="Run Info").grid(column=0, row=0, sticky=N, pady=5)
         ttk.Label(view_frame, text="PPG Parameters").grid(column=1, row=0, sticky=N, pady=5)
@@ -324,7 +325,8 @@ class fileviewer(object):
         except AttributeError:
             pass
             
-        key_order_sw.append('')
+        if key_order_sw[-1] != '':
+            key_order_sw.append('')
                 
         # cryo options
         try: 
@@ -376,7 +378,9 @@ class fileviewer(object):
     
         # rf dac
         if mode != 'SLR':
-            key_order_sw.append('')
+            if key_order_sw[-1] != '':
+                key_order_sw.append('')
+            
             try: 
                 data_sw['rf_dac'] = "%d" % int(data.camp.rf_dac.mean)
                 key_order_sw.append('rf_dac')
@@ -389,7 +393,8 @@ class fileviewer(object):
             except AttributeError:
                 pass    
         
-        key_order_sw.append('')
+        if key_order_sw[-1] != '':
+            key_order_sw.append('')
         
         # rates and counts
         hist = ('F+', 'F-', 'B-', 'B+') if data.area == 'BNMR' \
@@ -432,7 +437,8 @@ class fileviewer(object):
         except (AttributeError, KeyError):
             pass
         
-        key_order_sw.append('')
+        if key_order_sw[-1] != '':
+            key_order_sw.append('')
         
         hist = ('F+', 'F-', 'B-', 'B+')    
         try: 
@@ -479,30 +485,6 @@ class fileviewer(object):
         except AttributeError:
             pass
         
-        try:
-            data_se["Doppler Tube CH0"] = "%.3f +/- %.3f V" % \
-                    (np.around(data.epics.dopplertube_ch0.mean, 3), 
-                     np.around(data.epics.dopplertube_ch0.std, 3))
-            key_order_se.append('Doppler Tube CH0')
-        except AttributeError:
-            pass
-        
-        try:
-            data_se["Doppler Tube CH1"] = "%.3f +/- %.3f V" % \
-                    (np.around(data.epics.dopplertube_ch1.mean, 3), 
-                     np.around(data.epics.dopplertube_ch1.std, 3))
-            key_order_se.append('Doppler Tube CH1')
-        except AttributeError:
-            pass
-        
-        try:
-            data_se["Doppler Tube CH2"] = "%.3f +/- %.3f V" % \
-                    (np.around(data.epics.dopplertube_ch2.mean, 3), 
-                     np.around(data.epics.dopplertube_ch2.std, 3))
-            key_order_se.append('Doppler Tube CH2')
-        except AttributeError:
-            pass
-        
         # get data: beam energy
         try: 
             init_bias = data.epics.target_bias.mean
@@ -531,7 +513,37 @@ class fileviewer(object):
         except AttributeError:
             pass
         
-        key_order_se.append('')
+        if key_order_se[-1] != '':
+            key_order_se.append('')
+        
+        # doppler tubes
+        try:
+            data_se["Doppler Tube CH0"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch0.mean, 3), 
+                     np.around(data.epics.dopplertube_ch0.std, 3))
+            key_order_se.append('Doppler Tube CH0')
+        except AttributeError:
+            pass
+        
+        try:
+            data_se["Doppler Tube CH1"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch1.mean, 3), 
+                     np.around(data.epics.dopplertube_ch1.std, 3))
+            key_order_se.append('Doppler Tube CH1')
+        except AttributeError:
+            pass
+        
+        try:
+            data_se["Doppler Tube CH2"] = "%.3f +/- %.3f V" % \
+                    (np.around(data.epics.dopplertube_ch2.mean, 3), 
+                     np.around(data.epics.dopplertube_ch2.std, 3))
+            key_order_se.append('Doppler Tube CH2')
+        except AttributeError:
+            pass
+        
+        if key_order_se[-1] != '':
+            key_order_se.append('')
+        
         
         # laser stuff
         try: 
@@ -647,7 +659,7 @@ class fileviewer(object):
                 pass
             
         # get 1F specific data
-        elif data.mode == '1f':
+        elif data.mode in ('1f', '1x'):
             
             # ppg timing box
             try:
@@ -673,6 +685,18 @@ class fileviewer(object):
             
             key_order_ne.append('')
             
+            # titles for frequencies
+            if data.mode == '1x':
+                nregions = len([k for k in data.ppg.keys() if 'fine freq start' in k])
+                
+                titles = ['Main scan']
+                for i in range(nregions):
+                    titles.append('Fine region %d' % (i+1))
+                titles = [titles[i].ljust(14) for i in range(len(titles))]
+                
+                data_ne['Scan region'] = ''.join(titles)
+                key_order_ne.append('Scan region')
+            
             # PSM RF - Frequency
             try:
                 start = int(data.ppg.freq_start.mean)
@@ -703,7 +727,7 @@ class fileviewer(object):
                 pass
             
             try:
-                center = (stop-start)/2
+                center = (stop+start)/2
                 data_ne['Center frequency'] = '%d Hz' % center
                 key_order_ne.append('Center frequency')
             except NameError:
@@ -754,6 +778,45 @@ class fileviewer(object):
             except AttributeError:
                 pass
                 
+            i = 1
+            while True: 
+                
+                string_len = 14 * i
+                
+                try:
+                    
+                    start = int(data.ppg['fine freq start %d (hz)' % i].mean)
+                    string = data_ne['Start frequency'].ljust(string_len)
+                    data_ne['Start frequency'] = string + '%d Hz' % start
+                    
+                    stop = int(data.ppg['fine freq end %d (hz)' % i].mean)
+                    string = data_ne['End frequency'].ljust(string_len)
+                    data_ne['End frequency'] = string + '%d Hz' % stop
+                    
+                    gap = int(data.ppg['fine freq increment %d (hz)' % i].mean)
+                    string = data_ne['Frequency scan gap'].ljust(string_len) 
+                    data_ne['Frequency scan gap'] = string + '%d Hz' % gap
+                    
+                    center = (start+stop)/2
+                    string = data_ne['Center frequency'].ljust(string_len)
+                    data_ne['Center frequency'] = string + '%d Hz' % center
+                    
+                    width = (stop-start)
+                    string = data_ne['Full scan width'].ljust(string_len)
+                    data_ne['Full scan width'] = string + '%d Hz' % width
+                    
+                    nsteps = int((stop-start)/gap)
+                    string = data_ne['Num frequency steps'].split('(')[0]
+                    string = string.ljust(string_len)
+                    data_ne['Num frequency steps'] = string + '%d' % nsteps
+                    
+                except KeyError:
+                    break
+                except NameError:
+                    pass
+                
+                i += 1
+                
         # get 1W specific data
         elif data.mode == '1w':
             
